import type { Hash } from "@siteimprove/alfa-hash";
import { type Parser as CSSParser } from "../../syntax/index.js";
import { Angle, Number, Percentage } from "../numeric/index.js";
import { Format } from "./format.js";
import { RGB } from "./rgb.js";
type ToCanonical<T extends Angle | Number | Percentage<"percentage">> = T extends Angle ? Angle.Canonical : T extends Number ? Number.Canonical : T extends Percentage ? Percentage.Canonical : Angle.Canonical | Number.Canonical | Percentage.Canonical;
/**
 * @public
 */
export declare class HSL<H extends Number.Fixed | Angle.Fixed = Number.Fixed | Angle.Fixed, A extends Number.Fixed | Percentage.Fixed<"percentage"> = Number.Fixed | Percentage.Fixed<"percentage">> extends Format<"hsl"> {
    static of<H extends Number.Canonical | Angle.Canonical, A extends Number.Canonical | Percentage.Canonical, S extends Percentage<"percentage">, L extends Percentage<"percentage">>(hue: H, saturation: S, lightness: L, alpha: A): HSL<H, A>;
    static of<H extends Number | Angle, A extends Number | Percentage<"percentage">, S extends Percentage<"percentage">, L extends Percentage<"percentage">>(hue: H, saturation: S, lightness: L, alpha: A): HSL<ToCanonical<H>, ToCanonical<A>>;
    private readonly _hue;
    private readonly _saturation;
    private readonly _lightness;
    private readonly _red;
    private readonly _green;
    private readonly _blue;
    private readonly _alpha;
    private constructor();
    get hue(): H;
    get saturation(): Percentage.Canonical;
    get lightness(): Percentage.Canonical;
    get red(): Percentage.Canonical;
    get green(): Percentage.Canonical;
    get blue(): Percentage.Canonical;
    get alpha(): A;
    resolve(): RGB.Canonical;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): HSL.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace HSL {
    interface JSON extends Format.JSON<"hsl"> {
        hue: Number.Fixed.JSON | Angle.Fixed.JSON;
        saturation: Percentage.Fixed.JSON;
        lightness: Percentage.Fixed.JSON;
        alpha: Number.Fixed.JSON | Percentage.Fixed.JSON;
    }
    function isHSL<H extends Number.Fixed | Angle.Fixed, A extends Number.Fixed | Percentage.Fixed>(value: unknown): value is HSL<H, A>;
    /**
     * {@link https://drafts.csswg.org/css-color/#funcdef-hsl}
     */
    const parse: CSSParser<HSL>;
}
export {};
//# sourceMappingURL=hsl.d.ts.map