import type { Hash } from "@siteimprove/alfa-hash";
import { Keyword } from "./textual/keyword.js";
import type { Resolvable } from "./resolvable.js";
import { Value } from "./value.js";
import { type Parser as CSSParser } from "../syntax/index.js";
/**
 * {@link https://developer.mozilla.org/en-US/docs/Web/CSS/contain#formal_syntax}
 *
 * @public
 */
export type Contain = Keyword<"none"> | Keyword<"strict"> | Keyword<"content"> | ContainFlags;
/**
 * @public
 */
export declare class ContainFlags extends Value<"contain-flags", false> implements Resolvable<ContainFlags, never> {
    static of(size: boolean, inlineSize: boolean, layout: boolean, style: boolean, paint: boolean): ContainFlags;
    private readonly _size;
    private readonly _inlineSize;
    private readonly _layout;
    private readonly _style;
    private readonly _paint;
    private constructor();
    get size(): boolean;
    get inlineSize(): boolean;
    get layout(): boolean;
    get style(): boolean;
    get paint(): boolean;
    resolve(): ContainFlags;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): ContainFlags.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace ContainFlags {
    interface JSON extends Value.JSON<"contain-flags"> {
        size: boolean;
        inlineSize: boolean;
        layout: boolean;
        style: boolean;
        paint: boolean;
    }
    function isContainFlags(value: unknown): value is ContainFlags;
    const parse: CSSParser<ContainFlags>;
}
/**
 * @public
 */
export declare namespace Contain {
    const parse: CSSParser<Contain>;
}
//# sourceMappingURL=contain.d.ts.map