import type { Hash } from "@siteimprove/alfa-hash";
import { type Parser as CSSParser } from "../../../../syntax/index.js";
import { LengthPercentage } from "../../../numeric/index.js";
import type { PartiallyResolvable, Resolvable } from "../../../resolvable.js";
import { Value } from "../../../value.js";
/**
 * {@link https://drafts.csswg.org/css-images/#valdef-ending-shape-ellipse}
 *
 * @internal
 */
export declare class Ellipse<R extends LengthPercentage = LengthPercentage> extends Value<"ellipse", Value.HasCalculation<[R, R]>> implements Resolvable<Ellipse.Canonical, Ellipse.Resolver>, PartiallyResolvable<Ellipse.PartiallyResolved, Ellipse.PartialResolver> {
    static of<R extends LengthPercentage>(horizontal: R, vertical: R): Ellipse<R>;
    private readonly _horizontal;
    private readonly _vertical;
    private constructor();
    get horizontal(): R;
    get vertical(): R;
    resolve(resolver: Ellipse.Resolver): Ellipse.Canonical;
    partiallyResolve(resolver: Ellipse.PartialResolver): Ellipse.PartiallyResolved;
    equals(value: Ellipse): boolean;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Ellipse.JSON;
    toString(): string;
}
/**
 * @internal
 */
export declare namespace Ellipse {
    type Canonical = Ellipse<LengthPercentage.Canonical>;
    type PartiallyResolved = Ellipse<LengthPercentage.PartiallyResolved>;
    interface JSON extends Value.JSON<"ellipse"> {
        horizontal: LengthPercentage.JSON;
        vertical: LengthPercentage.JSON;
    }
    type Resolver = LengthPercentage.Resolver;
    type PartialResolver = LengthPercentage.PartialResolver;
    function isEllipse(value: unknown): value is Ellipse;
    const parse: CSSParser<Ellipse>;
}
//# sourceMappingURL=ellipse.d.ts.map