import type { Hash } from "@siteimprove/alfa-hash";
import type { Serializable } from "@siteimprove/alfa-json";
import type { Option } from "@siteimprove/alfa-option";
import { type Parser as CSSParser } from "../../syntax/index.js";
import { LengthPercentage } from "../numeric/index.js";
import type { PartiallyResolvable, Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { BasicShape } from "./basic-shape.js";
import { Corner } from "./corner.js";
/**
 * {@link https://drafts.csswg.org/css-shapes/#funcdef-inset}
 *
 * @public
 */
export declare class Inset<O extends Inset.Offset = Inset.Offset, C extends Corner = Corner> extends BasicShape<"inset", HasCalculation<O, C>> implements Resolvable<Inset.Canonical, Inset.Resolver>, PartiallyResolvable<Inset.PartiallyResolved, Inset.PartialResolver> {
    static of<O extends Inset.Offset = Inset.Offset, C extends Corner = Corner>(offsets: readonly [O, O, O, O], corners: Option<readonly [C, C, C, C]>): Inset<O, C>;
    private readonly _offsets;
    private readonly _corners;
    private constructor();
    get offsets(): readonly [O, O, O, O];
    get corners(): Option<readonly [C, C, C, C]>;
    get top(): O;
    get right(): O;
    get bottom(): O;
    get left(): O;
    get topLeft(): Option<C>;
    get topRight(): Option<C>;
    get bottomRight(): Option<C>;
    get bottomLeft(): Option<C>;
    resolve(resolver: Inset.Resolver): Inset.Canonical;
    partiallyResolve(resolver: Inset.PartialResolver): Inset.PartiallyResolved;
    equals(value: Inset): boolean;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Inset.JSON<O, C>;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Inset {
    type Canonical = Inset<LengthPercentage.Canonical, Corner.Canonical>;
    type PartiallyResolved = Inset<LengthPercentage.PartiallyResolved, Corner.PartiallyResolved>;
    interface JSON<O extends Offset = Offset, C extends Corner = Corner> extends BasicShape.JSON<"inset"> {
        offsets: Serializable.ToJSON<readonly [O, O, O, O]>;
        corners: Option.JSON<readonly [C, C, C, C]>;
    }
    type Offset = LengthPercentage;
    type Resolver = LengthPercentage.Resolver;
    type PartialResolver = LengthPercentage.PartialResolver;
    function isInset(value: unknown): value is Inset;
    const parse: CSSParser<Inset>;
}
/**
 * Putting this in the Inset namespace clashes with the one in the parent
 * Value namespace that it inherit from (through the classes of the same names)
 */
type HasCalculation<O extends Inset.Offset, C extends Corner> = Value.HasCalculation<[
    O,
    C extends readonly [infer R extends LengthPercentage, any] ? R : C,
    C extends readonly [any, infer R extends LengthPercentage] ? R : C
]>;
export {};
//# sourceMappingURL=inset.d.ts.map