import type { Hash } from "@siteimprove/alfa-hash";
import { Parser } from "@siteimprove/alfa-parser";
import { Length } from "../numeric/index.js";
import type { Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { Function } from "./function.js";
/**
 * @public
 */
export declare class Perspective<D extends Length = Length> extends Function<"perspective", Value.HasCalculation<[D]>> implements Resolvable<Perspective.Canonical, Perspective.Resolver> {
    static of<D extends Length>(depth: D): Perspective<D>;
    private readonly _depth;
    private constructor();
    get depth(): D;
    resolve(resolver: Perspective.Resolver): Perspective.Canonical;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Perspective.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Perspective {
    type Canonical = Perspective<Length.Canonical>;
    interface JSON extends Function.JSON<"perspective"> {
        depth: Length.JSON;
    }
    type Resolver = Length.Resolver;
    function isPerspective<D extends Length.Fixed>(value: unknown): value is Perspective<D>;
    /**
     * {@link https://drafts.csswg.org/css-transforms-2/#funcdef-perspective}
     */
    const parse: Parser<import("@siteimprove/alfa-slice").Slice<import("../../syntax/token.js").Token>, Perspective<Length<import("../../index.js").Unit.Length>>, string, []>;
    /**
     * {@link https://developer.mozilla.org/en-US/docs/Web/CSS/perspective}
     */
    const parseProp: Parser<import("@siteimprove/alfa-slice").Slice<import("../../syntax/token.js").Token>, Perspective<Length<import("../../index.js").Unit.Length>>, string, []>;
}
//# sourceMappingURL=perspective.d.ts.map