import type { Hash } from "@siteimprove/alfa-hash";
import { Parser } from "@siteimprove/alfa-parser";
import { type Parser as CSSParser } from "../../syntax/index.js";
import { Unit } from "../../unit/index.js";
import { Length, LengthPercentage } from "../numeric/index.js";
import type { PartiallyResolvable, Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { Function } from "./function.js";
/**
 * @public
 */
export declare class Translate<X extends LengthPercentage = LengthPercentage, Y extends LengthPercentage = LengthPercentage, Z extends Length = Length> extends Function<"translate", Value.HasCalculation<[X, Y, Z]>> implements Resolvable<Translate.Canonical, Translate.Resolver>, PartiallyResolvable<Translate.PartiallyResolved, Translate.PartialResolver> {
    static of<X extends LengthPercentage = LengthPercentage, Y extends LengthPercentage = LengthPercentage, Z extends Length = Length>(x: X, y: Y, z: Z): Translate<X, Y, Z>;
    private readonly _x;
    private readonly _y;
    private readonly _z;
    private constructor();
    get x(): X;
    get y(): Y;
    get z(): Z;
    resolve(resolver: Translate.Resolver): Translate.Canonical;
    partiallyResolve(resolver: Translate.PartialResolver): Translate.PartiallyResolved;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Translate.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Translate {
    type Canonical = Translate<LengthPercentage.Canonical, LengthPercentage.Canonical, Length.Canonical>;
    type PartiallyResolved = Translate<LengthPercentage.PartiallyResolved, LengthPercentage.PartiallyResolved, Length.Canonical>;
    interface JSON extends Function.JSON<"translate"> {
        x: LengthPercentage.JSON;
        y: LengthPercentage.JSON;
        z: Length.JSON;
    }
    type Resolver = LengthPercentage.Resolver;
    type PartialResolver = LengthPercentage.PartialResolver & Length.Resolver;
    function isTranslate<X extends LengthPercentage, Y extends LengthPercentage, Z extends Length>(value: unknown): value is Translate<X, Y, Z>;
    const parse: CSSParser<Translate>;
    /**
     * {@link https://developer.mozilla.org/en-US/docs/Web/CSS/translate}
     */
    const parseProp: Parser<import("@siteimprove/alfa-slice").Slice<import("../../syntax/token.js").Token>, Translate<LengthPercentage<Unit.Length>, LengthPercentage<Unit.Length>, Length.Fixed<"px">> | Translate<LengthPercentage<Unit.Length>, LengthPercentage<Unit.Length>, Length>, string, []>;
}
//# sourceMappingURL=translate.d.ts.map